@@ -263,6 +263,8 @@ cb_change_button (gpointer data)
 {
   button_change_id = 0;
 
+  /* TODO: find out why GTK+ needs this to work (see #364371) */
+  gtk_button_set_label (GTK_BUTTON (data), _("Play"));
   gtk_button_set_label (GTK_BUTTON (data), GTK_STOCK_MEDIA_PLAY);
 
   /* once */
@@ -305,6 +307,8 @@ cb_state (GstBus *bus, GstMessage *message, gpointer user_data)
     gtk_statusbar_push (GTK_STATUSBAR (statusbar), 0, "");
     current_track = -1;
   } else if (transition == GST_STATE_CHANGE_PAUSED_TO_PLAYING) {
+    /* TODO: find out why GTK+ needs this to work (see #364371) */
+    gtk_button_set_label (GTK_BUTTON (play_button), _("Pause"));
     gtk_button_set_label (GTK_BUTTON (play_button), GTK_STOCK_MEDIA_PAUSE);
     if (id)
       g_source_remove (id);
